==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/sl/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Potrdite množičn izbris sredstev',
  'bulk_delete_help'	=> 'Pregled sredstev za množično brisanje je v seznamu spodaj. Ko bodo sredstva izbrisana, jih je mogoče obnoviti, vendar ne bodo povezana z nobenimi uporabnikom, kot so jim trenutno dodeljena.',
  'bulk_delete_warn'	=> 'Brisali boste: asset_count sredstev.',
	'bulk_update'		=> 'Množično posodabljanje sredstev',
	'bulk_update_help'	=> 'Ta obrazec vam omogoča, da posodobite več sredstev hkrati. Izpolnite le polja, ki jih morate spremeniti. Vsa polja, ki ostanejo prazna, bodo ostala nespremenjena. ',
	'bulk_update_warn'	=> 'Uredili boste lastnosti asset_count sredstev.',
    'checkedout_to'		=> 'Izdano osebi',
    'checkout_date'		=> 'Datum izdaje',
    'checkin_date'		=> 'Datum sprejema',
    'checkout_to'		=> 'Izdano osebi',
    'cost'				=> 'Stroški nakupa',
    'create'			=> 'Ustvari sredstvo',
    'date'				=> 'Datum nakupa',
    'depreciation'	    => 'Amortizacija',
    'depreciates_on'	=> 'Amortizacija na',
    'default_location'	=> 'Privzeta lokacija',
    'eol_date'			=> 'EOL datum',
    'eol_rate'			=> 'EOL stopnja',
    'expected_checkin'  => 'Predviden datum dobave',
    'expires'			=> 'Poteče',
    'fully_depreciated'	=> 'Popolnoma amortiziran',
    'help_checkout'		=> 'Če želite dodeliti to sredstvo takoj, izberite »Pripravljen za razporeditev « s seznama statusa zgoraj. ',
    'mac_address'		=> 'Mac naslov',
    'manufacturer'		=> 'Proizvajalec',
    'model'				=> 'Model',
    'months'			=> 'mesecev',
    'name'				=> 'Ime sredstva',
    'notes'				=> 'Opombe',
    'order'				=> 'Številka naročila',
    'qr'				=> 'QR-koda',
    'requestable'		=> 'Uporabniki lahko zahtevajo to sredstvo',
    'select_statustype'	=> 'Izberite vrsto statusa',
    'serial'			=> 'Serijska številka',
    'status'			=> 'Status',
    'tag'				=> 'Oznaka sredstva',
    'update'			=> 'Posodobitev sredstva',
    'warranty'			=> 'Garancija',
		'warranty_expires'		=> 'Garancija poteče',
    'years'				=> 'let',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/sl/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potrdite množičn izbris sredstev',
  'bulk_delete_help'	=> 'Pregled sredstev za množično brisanje je v seznamu spodaj. Ko bodo sredstva izbrisana, jih je mogoče obnoviti, vendar ne bodo povezana z nobenimi uporabnikom, kot so jim trenutno dodeljena.',
  'bulk_delete_warn'	=> 'Brisali boste: asset_count sredstev.',
    'bulk_update'		=> 'Množično posodabljanje sredstev',
    'bulk_update_help'	=> 'Ta obrazec vam omogoča, da posodobite več sredstev hkrati. Izpolnite le polja, ki jih morate spremeniti. Vsa polja, ki ostanejo prazna, bodo ostala nespremenjena. ',
    'bulk_update_warn'	=> 'Uredili boste lastnosti asset_count sredstev.',
    'checkedout_to'		=> 'Izdano osebi',
    'checkout_date'		=> 'Datum izdaje',
    'checkin_date'		=> 'Datum sprejema',
    'checkout_to'		=> 'Izdano osebi',
    'cost'				=> 'Stroški nakupa',
    'create'			=> 'Ustvari sredstvo',
    'date'				=> 'Datum nakupa',
    'depreciation'	    => 'Amortizacija',
    'depreciates_on'	=> 'Amortizacija na',
    'default_location'	=> 'Privzeta lokacija',
    'eol_date'			=> 'EOL datum',
    'eol_rate'			=> 'EOL stopnja',
    'expected_checkin'  => 'Predviden datum dobave',
    'expires'			=> 'Poteče',
    'fully_depreciated'	=> 'Popolnoma amortiziran',
    'help_checkout'		=> 'Če želite dodeliti to sredstvo takoj, izberite »Pripravljen za razporeditev « s seznama statusa zgoraj. ',
    'mac_address'		=> 'Mac naslov',
    'manufacturer'		=> 'Proizvajalec',
    'model'				=> 'Model',
    'months'			=> 'mesecev',
    'name'				=> 'Ime sredstva',
    'notes'				=> 'Opombe',
    'order'				=> 'Številka naročila',
    'qr'				=> 'QR-koda',
    'requestable'		=> 'Uporabniki lahko zahtevajo to sredstvo',
    'select_statustype'	=> 'Izberite vrsto statusa',
    'serial'			=> 'Serijska številka',
    'status'			=> 'Status',
    'tag'				=> 'Oznaka sredstva',
    'update'			=> 'Posodobitev sredstva',
    'warranty'			=> 'Garancija',
        'warranty_expires'		=> 'Garancija poteče',
    'years'				=> 'let',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
